import * as React from 'react';
import {FormWrapper, useField, useForm, useFields} from '../';

const Input = ({ name }: { name: string }) => {
    const { value, onChange } = useField<string>({ name });

    return <input type={"text"} value={value ?? ''} onChange={onChange} />
}

const Inputs = ({ name }: { name: string }) => {
    const { fields, append } = useFields({
        name,
        fieldArray: [
            {
                name: 'start_date',
                type: 'text',
            },
            {
                name: 'end_date',
                type: 'text',
            }
        ]
    });

    return (
        <>
            {fields.map((field, index) => field.map((f, i) => (
                <input key={`${f.name}-${i}`} type={f.type} value={(f.value ?? '') as string} onChange={f.onChange} />
            )))}

            <button type='button' onClick={() => append()}>Add</button>
        </>
    )
}

const Form = () => {
  const { handleSubmit, errors } = useForm({
    onSubmit: (values) => {
      console.log(values);
    },
    schema: {
        "name.first": {
            type: 'string',
            required: true,
            minLength: 3,
            maxLength: 10,
        },
        "dates": {
            type: 'array',
            required: true,
            minItems: 1,
            maxItems: 10,
            uniqueItems: true,
            schema: {
                "start_date": {
                    type: 'string',
                    required: true,
                    minLength: 3,
                    maxLength: 10,
                },
                "end_date": {
                    type: 'string',
                    required: true,
                    minLength: 3,
                    maxLength: 10,
                },
            }
        }
    }
  });

  console.log('errors', errors);

  return (
      <form onSubmit={handleSubmit}>
        <Input name={"name.first"} />
          <Inputs name={"dates"} />
        <button type={"submit"}>Submit</button>
      </form>
  )
}

export default {
  title: 'Example/Page',
  component: Form,
  decorators: [(Story) => <FormWrapper defaultValues={{ name: { first: 'test' }}}><Story /></FormWrapper>],
};

export const Story = () => <Form />;

